You are viewing a plain text version of this content. The canonical link for it is here.
Posted to pluto-scm@portals.apache.org by uk...@apache.org on 2007/06/07 11:59:39 UTC

svn commit: r545132 [2/2] - in /portals/pluto/branches/1.1-286-COMPATIBILITY: ./ pluto-container/src/main/java/org/apache/pluto/core/ pluto-container/src/main/java/org/apache/pluto/internal/impl/ pluto-container/src/main/java/org/apache/pluto/spi/ plut...

Modified: portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortalContext.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortalContext.java?view=diff&rev=545132&r1=545131&r2=545132
==============================================================================
--- portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortalContext.java (original)
+++ portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortalContext.java Thu Jun  7 02:59:35 2007
@@ -65,7 +65,7 @@
    * @return  All portal property names as an 
    *          <code>Enumeration</code> of <code>String</code> objects
    */
-  public java.util.Enumeration getPropertyNames();
+  public java.util.Enumeration<String> getPropertyNames();
 
 
   /**
@@ -79,7 +79,7 @@
    *          as an enumeration of <code>PortletMode</code> objects.
    */
 
-  public java.util.Enumeration getSupportedPortletModes();
+  public java.util.Enumeration<PortletMode> getSupportedPortletModes();
 
 
   /**
@@ -93,7 +93,7 @@
    *          as an enumertation of <code>WindowState</code> objects.
    */
 
-  public java.util.Enumeration getSupportedWindowStates();
+  public java.util.Enumeration<WindowState> getSupportedWindowStates();
 
 
   /**

Modified: portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletConfig.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletConfig.java?view=diff&rev=545132&r1=545131&r2=545132
==============================================================================
--- portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletConfig.java (original)
+++ portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletConfig.java Thu Jun  7 02:59:35 2007
@@ -119,7 +119,7 @@
    *                    portlet has no initialization parameters. 
    */
 
-  public java.util.Enumeration getInitParameterNames();
+  public java.util.Enumeration<String> getInitParameterNames();
   
 
   /**
@@ -134,8 +134,23 @@
    * @since 2.0 
    */
 
-  public java.util.Enumeration getPublicRenderParameterNames();
+  public java.util.Enumeration<String> getPublicRenderParameterNames();
   
   
+  /**
+   * Returns the default event namespace.
+   * This namespace is defined in the portlet deployment descriptor
+   * with the <code>default-event-namespace</code> element.
+   * <p>
+   * If no default namespace is defined in the portlet deployment
+   * descriptor this methods returns the XML default namespace 
+   * <code>XMLConstants.NULL_NS_URI</code>.
+   * 
+   * @return the default event namespace defined in the portlet deployment
+   *         descriptor, or <code>XMLConstants.NULL_NS_URI</code> is non is
+   *         defined.
+   * @since 2.0
+   */
+  public java.lang.String getDefaultEventNamespace();
 }
 

Modified: portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletContext.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletContext.java?view=diff&rev=545132&r1=545131&r2=545132
==============================================================================
--- portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletContext.java (original)
+++ portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletContext.java Thu Jun  7 02:59:35 2007
@@ -372,7 +372,7 @@
    * @see  #getInitParameter
    */
 
-  public java.util.Enumeration getInitParameterNames();
+  public java.util.Enumeration<String> getInitParameterNames();
 
 
   /**
@@ -487,7 +487,7 @@
    *          The keys in the map are of type String. The values in the map are of type
    *          String array (<code>String[]</code>).
    */
-  public java.util.Map getApplicationRuntimeOptions();
+  public java.util.Map<String, String[]> getApplicationRuntimeOptions();
 
   /**
    * Returns the portlet level container runtime options
@@ -514,5 +514,5 @@
    *          The keys in the map are of type String. The values in the map are of type
    *          String array (<code>String[]</code>).
    */
-  public java.util.Map getPortletRuntimeOptions();
+  public java.util.Map<String, String[]> getPortletRuntimeOptions();
 }

Modified: portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletException.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletException.java?view=diff&rev=545132&r1=545131&r2=545132
==============================================================================
--- portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletException.java (original)
+++ portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletException.java Thu Jun  7 02:59:35 2007
@@ -43,6 +43,7 @@
 
   private Throwable _cause;
 
+  private static final long serialVersionUID = 1L;
 
   /**
    * Constructs a new portlet exception.

Modified: portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletMode.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletMode.java?view=diff&rev=545132&r1=545131&r2=545132
==============================================================================
--- portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletMode.java (original)
+++ portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletMode.java Thu Jun  7 02:59:35 2007
@@ -159,3 +159,4 @@
       return false;
   }
 }
+

Modified: portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletModeException.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletModeException.java?view=diff&rev=545132&r1=545131&r2=545132
==============================================================================
--- portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletModeException.java (original)
+++ portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletModeException.java Thu Jun  7 02:59:35 2007
@@ -41,6 +41,8 @@
 
   private transient PortletMode _mode = null;
 
+  private static final long serialVersionUID = 1L;
+
   /**
    * Constructs a new portlet mode exception with the given text and the
    * portlet mode that caused this exception. The

Modified: portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletPreferences.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletPreferences.java?view=diff&rev=545132&r1=545131&r2=545132
==============================================================================
--- portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletPreferences.java (original)
+++ portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletPreferences.java Thu Jun  7 02:59:35 2007
@@ -210,7 +210,7 @@
    *         or an empty <code>Enumeration</code> if no keys are
    *         available.
    */
-  public java.util.Enumeration getNames();
+  public java.util.Enumeration<String> getNames();
 
   /** 
    * Returns a <code>Map</code> of the preferences.
@@ -227,7 +227,7 @@
    *             String array (<code>String[]</code>).
    */
 
-  public java.util.Map getMap();
+  public java.util.Map<String, String[]> getMap();
 
 
   /**

Modified: portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletRequest.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletRequest.java?view=diff&rev=545132&r1=545131&r2=545132
==============================================================================
--- portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletResponse.java (original)
+++ portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletResponse.java Thu Jun  7 02:59:35 2007
@@ -25,8 +25,8 @@
  * DO NOT add / change / or delete method signatures!
  */
 /**
-  * Copyright 2006 IBM Corporation.
-  */
+ * Copyright 2006 IBM Corporation.
+ */
 
 package javax.portlet;
 

Modified: portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletSecurityException.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletSecurityException.java?view=diff&rev=545132&r1=545131&r2=545132
==============================================================================
--- portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletSecurityException.java (original)
+++ portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletSecurityException.java Thu Jun  7 02:59:35 2007
@@ -39,6 +39,8 @@
 public class PortletSecurityException extends PortletException
 {
 
+  private static final long serialVersionUID = 1L;
+
   private PortletSecurityException ()
   {
   }

Modified: portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletSession.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletSession.java?view=diff&rev=545132&r1=545131&r2=545132
==============================================================================
--- portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletSession.java (original)
+++ portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletSession.java Thu Jun  7 02:59:35 2007
@@ -30,6 +30,8 @@
 
 package javax.portlet;
 
+import java.util.Map;
+
 
 
 /**
@@ -138,7 +140,7 @@
    *					invalidated session   
    */
   
-  public java.util.Enumeration getAttributeNames();
+  public java.util.Enumeration<String> getAttributeNames();
 
 
   /**
@@ -159,7 +161,7 @@
    *					invalidated session, or the scope is unkown to the container.   
    */
   
-  public java.util.Enumeration getAttributeNames(int scope);
+  public java.util.Enumeration<String> getAttributeNames(int scope);
 
   /**
    * Returns the time when this session was created, measured in 
@@ -378,4 +380,44 @@
 
   public PortletContext getPortletContext ();
 
+  /** 
+   * Returns a <code>Map</code> of the session attributes in
+   * the portlet session scope.
+   * <p>
+   * The values in the returned <code>Map</code> are from type
+   * String array (<code>String[]</code>).
+   * <p>
+   * If no session attributes exist this method returns an empty <code>Map</code>.
+   *
+   * @return     an immutable <code>Map</code> containing the session attributes in the  
+   *             portlet session scope as keys and attribute values as map values, or an empty <code>Map</code>
+   *             if no session attributes exist. The keys in the
+   *             map are of type String, the values of type
+   *             String array (<code>String[]</code>).
+   *  @since 2.0
+   */
+  public Map<String, String[]> getMap();  
+
+  /** 
+   * Returns a <code>Map</code> of the session attributes in
+   * the given session scope.
+   * <p>
+   * The values in the returned <code>Map</code> are from type
+   * String array (<code>String[]</code>).
+   * <p>
+   * If no session attributes exist this method returns an empty <code>Map</code>.
+   *
+   * @param scope               session scope of this attribute
+   * 
+   * @return     an immutable <code>Map</code> containing the session attributes in the  
+   *             given scope as keys and attribute values as map values, or an empty <code>Map</code>
+   *             if no session attributes exist. The keys in the
+   *             map are of type String, the values of type
+   *             String array (<code>String[]</code>).
+   *  @since 2.0
+   */
+  public Map<String, String[]> getMap(int scope);  
+
 }
+
+

Added: portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/ProcessAction.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/ProcessAction.java?view=auto&rev=545132
==============================================================================
--- portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/ProcessAction.java (added)
+++ portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/ProcessAction.java Thu Jun  7 02:59:35 2007
@@ -0,0 +1,58 @@
+/*  Licensed to the Apache Software Foundation (ASF) under one
+ *  or more contributor license agreements.  See the NOTICE file
+ *  distributed with this work for additional information
+ *  regarding copyright ownership.  The ASF licenses this file
+ *  to you under the Apache License, Version 2.0 (the
+ *  "License"); you may not use this file except in compliance
+ *  with the License.  You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *  Unless required by applicable law or agreed to in writing,
+ *  software distributed under the License is distributed on an
+ *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ *  KIND, either express or implied.  See the License for the
+ *  specific language governing permissions and limitations
+ *  under the License.
+ */
+/*
+ * NOTE: this source code is based on an early draft version of JSR 286 and not intended for product
+ * implementations. This file may change or vanish in the final version of the JSR 286 specification.
+ */
+/*
+ * This source code implements specifications defined by the Java
+ * Community Process. In order to remain compliant with the specification
+ * DO NOT add / change / or delete method signatures!
+ */
+/*
+ * Copyright 2006 IBM Corporation.
+ *
+ */
+package javax.portlet;
+
+import java.lang.annotation.ElementType;
+import java.lang.annotation.Retention;
+import java.lang.annotation.Target;
+
+/**
+ * Annotation for marking a method for processing
+ * a specific action.
+ * The <code>GenericPortlet</code> tries to dispatch to methods annotated 
+ * with the tag <code>@ProcessAction</code> for any received
+ * <code>processAction</code> call.
+ *
+ * @since 2.0
+ */
+@Target(ElementType.METHOD)
+@Retention(java.lang.annotation.RetentionPolicy.RUNTIME)
+public @interface ProcessAction {
+	/**
+	 * Name of the action.
+	 * Must be set on the 
+	 * <code>ActionURL</code> as value of the 
+	 * parameter <code>javax.portlet.action</code>.
+	 * 
+	 * @return  action name
+	 */
+	String name();
+}

Modified: portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/ProcessEvent.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/ProcessEvent.java?view=diff&rev=545132&r1=545131&r2=545132
==============================================================================
--- portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/ProcessEvent.java (original)
+++ portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/ProcessEvent.java Thu Jun  7 02:59:35 2007
@@ -30,9 +30,41 @@
  */
 package javax.portlet;
 
+import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;
+import java.lang.annotation.Target;
 
+/**
+ * Annotation for marking a method for handling
+ * a specific event.
+ * The <code>GenericPortlet</code> tries to dispatch to methods annotated 
+ * with the tag <code>@ProcessEvent</code> for any received event.
+ *
+ * @since 2.0
+ */
+@Target(ElementType.METHOD)
 @Retention(java.lang.annotation.RetentionPolicy.RUNTIME)
 public @interface ProcessEvent {
+    /**
+     * Event QName.
+     * Must be in the format:<br> 
+     * "{" + Namespace URI + "}" + local part.<br> 
+     * If the Namespace URI equals(XMLConstants.NULL_NS_URI), 
+     * only the local part is used 
+     * (like the <code>javax.xml.namespace.QName.toString()</code> method).
+     * 
+     * @return event QName.
+     */
+    String qname();
+    
+    /**
+     * Local part of the event name.
+     * The namespace for the events is either taken from the <code>default-event-namespace</code> element
+     * in the portlet deployment descriptor, or if this element is not provided
+     * the XML default namespace XMLConstants.NULL_NS_URI is used.
+     * 
+     * @return local part of the event name.
+     */
     String name();
+
 }

Modified: portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/ReadOnlyException.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/ReadOnlyException.java?view=diff&rev=545132&r1=545131&r2=545132
==============================================================================
--- portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/ReadOnlyException.java (original)
+++ portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/ReadOnlyException.java Thu Jun  7 02:59:35 2007
@@ -37,6 +37,7 @@
 
 public class ReadOnlyException extends PortletException
 {
+	  private static final long serialVersionUID = 1L;
 
   private ReadOnlyException ()
   {

Added: portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/RenderMode.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/RenderMode.java?view=auto&rev=545132
==============================================================================
--- portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/RenderMode.java (added)
+++ portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/RenderMode.java Thu Jun  7 02:59:35 2007
@@ -0,0 +1,55 @@
+/*  Licensed to the Apache Software Foundation (ASF) under one
+ *  or more contributor license agreements.  See the NOTICE file
+ *  distributed with this work for additional information
+ *  regarding copyright ownership.  The ASF licenses this file
+ *  to you under the Apache License, Version 2.0 (the
+ *  "License"); you may not use this file except in compliance
+ *  with the License.  You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *  Unless required by applicable law or agreed to in writing,
+ *  software distributed under the License is distributed on an
+ *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ *  KIND, either express or implied.  See the License for the
+ *  specific language governing permissions and limitations
+ *  under the License.
+ */
+/*
+ * NOTE: this source code is based on an early draft version of JSR 286 and not intended for product
+ * implementations. This file may change or vanish in the final version of the JSR 286 specification.
+ */
+/*
+ * This source code implements specifications defined by the Java
+ * Community Process. In order to remain compliant with the specification
+ * DO NOT add / change / or delete method signatures!
+ */
+/*
+ * Copyright 2006 IBM Corporation.
+ *
+ */
+package javax.portlet;
+
+import java.lang.annotation.ElementType;
+import java.lang.annotation.Retention;
+import java.lang.annotation.Target;
+
+/**
+ * Annotation for marking a method for handling
+ * a specific portlet mode in the render phase.
+ * The <code>GenericPortlet</code> tries to dispatch to methods annotated 
+ * with the tag <code>@RenderMode</code> for any received render call.
+ *
+ * @since 2.0
+ */
+@Target(ElementType.METHOD)
+@Retention(java.lang.annotation.RetentionPolicy.RUNTIME)
+public @interface RenderMode {
+	/**
+	 * Name of the render mode.
+	 * 
+	 * @return  render mode name
+	 */
+	String name();
+
+}

Modified: portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/RenderRequest.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/RenderRequest.java?view=diff&rev=545132&r1=545131&r2=545132
==============================================================================
--- portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/RenderRequest.java (original)
+++ portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/RenderRequest.java Thu Jun  7 02:59:35 2007
@@ -75,4 +75,7 @@
      * @since 2.0
      */
     public String getETag();
+    
+
+
 }

Modified: portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/RenderResponse.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/RenderResponse.java?view=diff&rev=545132&r1=545131&r2=545132
==============================================================================
--- portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/RenderResponse.java (original)
+++ portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/RenderResponse.java Thu Jun  7 02:59:35 2007
@@ -25,8 +25,8 @@
  * DO NOT add / change / or delete method signatures!
  */
 /**
-  * Copyright 2006 IBM Corporation.
-  */
+ * Copyright 2006 IBM Corporation.
+ */
 
 package javax.portlet;
 
@@ -69,11 +69,12 @@
      * portlet deployment descriptor are meaningful new portlet modes.
      * 
      * @param portletModes
+     *            <code>Enumeration</code> of <code>PortletMode</code> objects with the
      *            next possible portlet modes that the make sense from the
      *            portlet point of view, must not be <code>null</code> or an
      *            empty enumeration.
      * @since 2.0
      */
-	public void setNextPossiblePortletModes(java.util.Enumeration portletModes);
+	public void setNextPossiblePortletModes(java.util.Enumeration<PortletMode> portletModes);
 
 }

Modified: portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/ResourceRequest.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/ResourceRequest.java?view=diff&rev=545132&r1=545131&r2=545132
==============================================================================
--- portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/ResourceRequest.java (original)
+++ portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/ResourceRequest.java Thu Jun  7 02:59:35 2007
@@ -85,7 +85,7 @@
      * if no resource ID was set onj the URL.
      * 
      * @return  the resource ID set on the ResourceURL,or <code>null</code>
-     *          if no resource ID was set onj the URL. 
+     *          if no resource ID was set on the URL. 
      */
     String getResourceID();
     

Modified: portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/ResourceResponse.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/ResourceResponse.java?view=diff&rev=545132&r1=545131&r2=545132
==============================================================================
--- portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/ResourceResponse.java (original)
+++ portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/ResourceResponse.java Thu Jun  7 02:59:35 2007
@@ -24,9 +24,10 @@
  * Community Process. In order to remain compliant with the specification
  * DO NOT add / change / or delete method signatures!
  */
-/**
-  * Copyright 2006 IBM Corporation.
-  */
+/*
+ * Copyright 2006 IBM Corporation.
+ *
+ */
 package javax.portlet;
 
 /**

Modified: portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/ResourceURL.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/ResourceURL.java?view=diff&rev=545132&r1=545131&r2=545132
==============================================================================
--- portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/ResourceURL.java (original)
+++ portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/ResourceURL.java Thu Jun  7 02:59:35 2007
@@ -24,9 +24,9 @@
  * Community Process. In order to remain compliant with the specification
  * DO NOT add / change / or delete method signatures!
  */
-/**
-  * Copyright 2006 IBM Corporation.
-  */
+/*
+ * Copyright 2006 IBM Corporation.
+ */
 package javax.portlet;
 
 /**

Modified: portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/StateAwareResponse.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/StateAwareResponse.java?view=diff&rev=545132&r1=545131&r2=545132
==============================================================================
--- portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/StateAwareResponse.java (original)
+++ portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/StateAwareResponse.java Thu Jun  7 02:59:35 2007
@@ -131,7 +131,7 @@
      *                has been called.
      */
 
-	public void setRenderParameters(java.util.Map parameters);
+	public void setRenderParameters(java.util.Map<String, String[]> parameters);
 
 	/**
      * Sets a String parameter for the render request.
@@ -196,11 +196,11 @@
      * @param name
      *            the event name to publish, must not be <code>null</code>
      * @param value
-     *            the value of this event, must not be <code>null</code> and
-     *            must have a valid JAXB binding and be serializable.
+     *            the value of this event, must have a valid JAXB binding and 
+     *            be serializable, or <code>null</code>.
      * 
      * @exception java.lang.IllegalArgumentException
-     *                if name or value is <code>null</code>, the value is not
+     *                if name is <code>null</code>, the value is not
      *                serializable, the value has not a valid JAXB binding, the
      *                object type of the value is not the same as specified in
      *                the portlet deployment descriptor for this event name.
@@ -209,23 +209,73 @@
 	public void setEvent(javax.xml.namespace.QName name, Object value);
 
 	/**
+     * Publishes an Event with the given payload in the default namespace.
+     * <p>
+     * The name is treated as local part of the event QName and the namespace
+     * is either taken from the <code>default-event-namespace</code> element
+     * in the portlet deployment descriptor, or if this element is not provided
+     * the XML default namespace XMLConstants.NULL_NS_URI is used.
+     * <p>
+     * The object type of the value must be compliant with the specified event
+     * type in the portlet deployment descriptor.
+     * <p>
+     * The value must have a valid JAXB binding and be serializable.
+     * 
+     * @param name
+     *            the local part of the event name to publish, must not be <code>null</code>
+     * @param value
+     *            the value of this event, must have a valid JAXB binding and 
+     *            be serializable, or <code>null</code>.
+     * 
+     * @exception java.lang.IllegalArgumentException
+     *                if name is <code>null</code>, the value is not
+     *                serializable, the value has not a valid JAXB binding, the
+     *                object type of the value is not the same as specified in
+     *                the portlet deployment descriptor for this event name.
+     * @since 2.0
+     */
+	public void setEvent(String name, Object value);
+
+	/**
      * Publishes an array of Events.
      * <p>
-<<<<<<< .mine
-     * All previously set events are cleared.
-=======
      * The events map must contain
      * <code>javax.xml.namespace.QName, Object</code> value pairs. The
      * <code>javax.xml.namespace.QName</code> value represents the event name
      * and the <code>Object</code> value represents the event payload. The
      * object types of the payload values must be compliant with the specified
      * event types for the event types in the portlet deployment descriptor.
->>>>>>> .r539908
+     * <p>
+     * The values must have a valid JAXB binding and be serializable.
+     * <p>
+     * The order of the events in the map does not imply the order of the
+     * delivery of the events.
+     * 
+     * @param events
+     *            the events to publish, must not be <code>null</code>
+     * 
+     * @exception java.lang.IllegalArgumentException
+     *                if events is <code>null</code>, a name in
+     *                events is <code>null</code>, a payload in events is not
+     *                serializable, a payload in events has not a valid JAXB
+     *                binding, the object type of a payload is not the same as
+     *                specified in the portlet deployment descriptor for this
+     *                event name.
+     * @see #setEvent(javax.xml.namespace.QName, Object)
+     * @since 2.0
+     */
+	public void setEvents(java.util.Map<javax.xml.namespace.QName, Object> events);
+
+	/**
+     * Publishes an array of Events in the default namespace.
      * <p>
      * The events map must contain
-     * <code>javax.xml.namespace.QName, Object</code> value pairs. The
-     * <code>javax.xml.namespace.QName</code> value represents the event name
-     * and the <code>Object</code> value represents the event payload. The
+     * <code>String, Object</code> value pairs. The
+     * <code>String</code> value represents the local part of the event name
+     * and the <code>Object</code> value represents the event payload. The namespace
+     * for the events is either taken from the <code>default-event-namespace</code> element
+     * in the portlet deployment descriptor, or if this element is not provided
+     * the XML default namespace XMLConstants.NULL_NS_URI is used. The
      * object types of the payload values must be compliant with the specified
      * event types for the event types in the portlet deployment descriptor.
      * <p>
@@ -238,16 +288,16 @@
      *            the events to publish, must not be <code>null</code>
      * 
      * @exception java.lang.IllegalArgumentException
-     *                if events is <code>null</code>, a name or payload in
+     *                if events is <code>null</code>, a name in
      *                events is <code>null</code>, a payload in events is not
      *                serializable, a payload in events has not a valid JAXB
      *                binding, the object type of a payload is not the same as
      *                specified in the portlet deployment descriptor for this
      *                event name.
-     * @see #setEvent(javax.xml.namespace.QName, Object)
+     * @see #setEvent(String, Object)
      * @since 2.0
      */
-	public void setEvents(java.util.Map events);
+	public void setDefaultNamspacedEvents(java.util.Map<String, Object> events);
 
 	/**
      * Returns a <code>Map</code> of the render parameters currently set on
@@ -265,7 +315,7 @@
      *         String. The values in the parameter map are of type String array (<code>String[]</code>).
      */
 
-	public java.util.Map getRenderParameterMap();
+	public java.util.Map<String, String[]> getRenderParameterMap();
 
 	/**
      * Returns the currently set portlet mode on this reponse.
@@ -286,4 +336,6 @@
      */
 
 	public WindowState getWindowState();
+
+
 }

Modified: portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/UnavailableException.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/UnavailableException.java?view=diff&rev=545132&r1=545131&r2=545132
==============================================================================
--- portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/UnavailableException.java (original)
+++ portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/UnavailableException.java Thu Jun  7 02:59:35 2007
@@ -42,6 +42,7 @@
     private boolean     permanent;         // needs admin action?
     private int         seconds;           // unavailability estimate
 
+    private static final long serialVersionUID = 1L;
 
     /**
      * 

Modified: portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/ValidatorException.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/ValidatorException.java?view=diff&rev=545132&r1=545131&r2=545132
==============================================================================
--- portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/ValidatorException.java (original)
+++ portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/ValidatorException.java Thu Jun  7 02:59:35 2007
@@ -26,34 +26,6 @@
  */
 /**
   * Copyright 2006 IBM Corporation.
-  *//*  Licensed to the Apache Software Foundation (ASF) under one
- *  or more contributor license agreements.  See the NOTICE file
- *  distributed with this work for additional information
- *  regarding copyright ownership.  The ASF licenses this file
- *  to you under the Apache License, Version 2.0 (the
- *  "License"); you may not use this file except in compliance
- *  with the License.  You may obtain a copy of the License at
- *
- *    http://www.apache.org/licenses/LICENSE-2.0
- *
- *  Unless required by applicable law or agreed to in writing,
- *  software distributed under the License is distributed on an
- *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- *  KIND, either express or implied.  See the License for the
- *  specific language governing permissions and limitations
- *  under the License.
- */
-/*
- * NOTE: this source code is based on an early draft version of JSR 286 and not intended for product
- * implementations. This file may change or vanish in the final version of the JSR 286 specification.
- */
-/*
- * This source code implements specifications defined by the Java
- * Community Process. In order to remain compliant with the specification
- * DO NOT add / change / or delete method signatures!
- */
-/**
-  * Copyright 2006 IBM Corporation.
   */
 
 package javax.portlet;
@@ -72,7 +44,8 @@
 public class ValidatorException extends PortletException
 {
 
-  private transient ArrayList failedKeyVector = new ArrayList();
+  private transient ArrayList<String> failedKeyVector = new ArrayList<String>();
+  private static final long serialVersionUID = 1L;
 
   private ValidatorException ()
   {
@@ -91,7 +64,7 @@
    *          keys that failed the validation; may be <code>null</code>
    */
 
-  public ValidatorException (String text, Collection failedKeys)
+  public ValidatorException (String text, Collection<String> failedKeys)
   {
     super (text);
     if ( failedKeys != null )
@@ -119,7 +92,7 @@
    *          keys that failed the validation; may be <code>null</code>
    */
   
-  public ValidatorException (String text, Throwable cause, Collection failedKeys)
+  public ValidatorException (String text, Throwable cause, Collection<String> failedKeys)
   {
     super(text, cause);
     if ( failedKeys != null )
@@ -140,7 +113,7 @@
    *          keys that failed the validation; may be <code>null</code>
    */
 
-  public ValidatorException (Throwable cause, Collection failedKeys)
+  public ValidatorException (Throwable cause, Collection<String> failedKeys)
   {
     super(cause);
     if ( failedKeys != null )

Modified: portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/WindowState.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/WindowState.java?view=diff&rev=545132&r1=545131&r2=545132
==============================================================================
--- portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/WindowState.java (original)
+++ portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/WindowState.java Thu Jun  7 02:59:35 2007
@@ -138,3 +138,4 @@
       return false;
   }
 }
+

Modified: portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/WindowStateException.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/WindowStateException.java?view=diff&rev=545132&r1=545131&r2=545132
==============================================================================
--- portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/WindowStateException.java (original)
+++ portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/WindowStateException.java Thu Jun  7 02:59:35 2007
@@ -40,6 +40,7 @@
 {
 
   private transient WindowState _state = null;
+  private static final long serialVersionUID = 1L;
 
   /**
    * Constructs a new portlet state exception with the given text. The

Modified: portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/filter/ActionRequestWrapper.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/filter/ActionRequestWrapper.java?view=diff&rev=545132&r1=545131&r2=545132
==============================================================================
--- portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/filter/ActionRequestWrapper.java (original)
+++ portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/filter/ActionRequestWrapper.java Thu Jun  7 02:59:35 2007
@@ -143,7 +143,7 @@
      * The default behavior of this method is to call 
      * <code>getAttributeNames()</code> on the wrapped request object.
      */
-    public Enumeration getAttributeNames() {
+    public Enumeration<String> getAttributeNames() {
         return request.getAttributeNames();
     }
 
@@ -191,7 +191,7 @@
      * The default behavior of this method is to call 
      * <code>getParameterMap()</code> on the wrapped request object.
      */
-    public Map getParameterMap() {
+    public Map<String, String[]> getParameterMap() {
         return request.getParameterMap();
     }
 
@@ -199,7 +199,7 @@
      * The default behavior of this method is to call 
      * <code>getParameterNames()</code> on the wrapped request object.
      */
-    public Enumeration getParameterNames() {
+    public Enumeration<String> getParameterNames() {
         return request.getParameterNames();
     }
 
@@ -255,7 +255,7 @@
      * The default behavior of this method is to call 
      * <code>getProperteis(name)</code> on the wrapped request object.
      */
-    public Enumeration getProperties(String name) {
+    public Enumeration<String> getProperties(String name) {
         return request.getProperties(name);
     }
 
@@ -271,7 +271,7 @@
      * The default behavior of this method is to call 
      * <code>getPropertyNames()</code> on the wrapped request object.
      */
-    public Enumeration getPropertyNames() {
+    public Enumeration<String> getPropertyNames() {
         return request.getPropertyNames();
     }
 
@@ -303,7 +303,7 @@
      * The default behavior of this method is to call 
      * <code>getResponseContentTypes()</code> on the wrapped request object.
      */
-    public Enumeration getResponseContentTypes() {
+    public Enumeration<String> getResponseContentTypes() {
         return request.getResponseContentTypes();
     }
 
@@ -445,5 +445,4 @@
     public Cookie[] getCookies() {
     	return request.getCookies();
     }
-
 }

Modified: portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/filter/ActionResponseWrapper.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/filter/ActionResponseWrapper.java?view=diff&rev=545132&r1=545131&r2=545132
==============================================================================
--- portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/filter/ActionResponseWrapper.java (original)
+++ portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/filter/ActionResponseWrapper.java Thu Jun  7 02:59:35 2007
@@ -5,7 +5,7 @@
  *  to you under the Apache License, Version 2.0 (the
  *  "License"); you may not use this file except in compliance
  *  with the License.  You may obtain a copy of the License at
- *  
+ *
  *    http://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing,
@@ -96,7 +96,7 @@
      * The default behavior of this method is to call 
      * <code>setEvents(events)</code> on the wrapped response object.
      */
-    public void setEvents(Map events) {
+    public void setEvents(Map<javax.xml.namespace.QName, Object> events) {
         response.setEvents(events);
     }
 
@@ -129,7 +129,7 @@
      * The default behavior of this method is to call 
      * <code>setRenderParameters(parameters)</code> on the wrapped response object.
      */
-    public void setRenderParameters(Map parameters) {
+    public void setRenderParameters(Map<String, String[]> parameters) {
         response.setRenderParameters(parameters);
     }
 
@@ -174,7 +174,6 @@
         return response.createResourceURL();
     }
 
-
     /**
      * The default behavior of this method is to call 
      * <code>encodeURL(path)</code> on the wrapped response object.
@@ -230,7 +229,7 @@
      * The default behavior of this method is to call 
      * <code>getRenderParameterMap()</code> on the wrapped response object.
      */
-    public Map getRenderParameterMap() {
+    public Map<String, String[]> getRenderParameterMap() {
         return response.getRenderParameterMap();
     }
 
@@ -249,4 +248,21 @@
     public void addProperty(Cookie cookie) {
         response.addProperty(cookie);
     }
+
+    /**
+     *  The default behavior of this method is to call 
+     * <code>setDefaultNamspacedEvents()</code> on the wrapped response object.
+     */
+	public void setDefaultNamspacedEvents(Map<String, Object> events) {
+		response.setDefaultNamspacedEvents(events);
+	}
+
+    /**
+     *  The default behavior of this method is to call 
+     * <code>setEvent()</code> on the wrapped response object.
+     */
+	public void setEvent(String name, Object value) {
+		response.setEvent(name, value);
+	}
+
 }

Modified: portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/filter/EventRequestWrapper.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/filter/EventRequestWrapper.java?view=diff&rev=545132&r1=545131&r2=545132
==============================================================================
--- portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/filter/EventRequestWrapper.java (original)
+++ portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/filter/EventRequestWrapper.java Thu Jun  7 02:59:35 2007
@@ -89,7 +89,7 @@
      * The default behavior of this method is to call 
      * <code>getAttributeNames()</code> on the wrapped request object.
      */
-    public Enumeration getAttributeNames() {
+    public Enumeration<String> getAttributeNames() {
         return request.getAttributeNames();
     }
 
@@ -137,7 +137,7 @@
      * The default behavior of this method is to call 
      * <code>getParameterMap()</code> on the wrapped request object.
      */
-    public Map getParameterMap() {
+    public Map<String, String[]> getParameterMap() {
         return request.getParameterMap();
     }
 
@@ -145,7 +145,7 @@
      * The default behavior of this method is to call 
      * <code>getParameterNames()</code> on the wrapped request object.
      */
-    public Enumeration getParameterNames() {
+    public Enumeration<String> getParameterNames() {
         return request.getParameterNames();
     }
 
@@ -201,7 +201,7 @@
      * The default behavior of this method is to call 
      * <code>getProperteis(name)</code> on the wrapped request object.
      */
-    public Enumeration getProperties(String name) {
+    public Enumeration<String> getProperties(String name) {
         return request.getProperties(name);
     }
 
@@ -217,7 +217,7 @@
      * The default behavior of this method is to call 
      * <code>getPropertyNames()</code> on the wrapped request object.
      */
-    public Enumeration getPropertyNames() {
+    public Enumeration<String> getPropertyNames() {
         return request.getPropertyNames();
     }
 
@@ -249,7 +249,7 @@
      * The default behavior of this method is to call 
      * <code>getResponseContentTypes()</code> on the wrapped request object.
      */
-    public Enumeration getResponseContentTypes() {
+    public Enumeration<String> getResponseContentTypes() {
         return request.getResponseContentTypes();
     }
 

Modified: portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/filter/EventResponseWrapper.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/filter/EventResponseWrapper.java?view=diff&rev=545132&r1=545131&r2=545132
==============================================================================
--- portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/filter/EventResponseWrapper.java (original)
+++ portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/filter/EventResponseWrapper.java Thu Jun  7 02:59:35 2007
@@ -24,9 +24,10 @@
  * Community Process. In order to remain compliant with the specification
  * DO NOT add / change / or delete method signatures!
  */
-/**
-  * Copyright 2006 IBM Corporation.
-  */
+/*
+ * Copyright 2006 IBM Corporation.
+ *
+ */
 package javax.portlet.filter;
 
 import java.util.Map;
@@ -88,7 +89,7 @@
       * The default behavior of this method is to call 
       * <code>setEvents(events)</code> on the wrapped response object.
       */
-     public void setEvents(Map events) {
+     public void setEvents(Map<javax.xml.namespace.QName, Object> events) {
          response.setEvents(events);
      }
 
@@ -121,7 +122,7 @@
       * The default behavior of this method is to call 
       * <code>setRenderParameters(parameters)</code> on the wrapped response object.
       */
-     public void setRenderParameters(Map parameters) {
+     public void setRenderParameters(Map<String, String[]> parameters) {
          response.setRenderParameters(parameters);
      }
 
@@ -221,7 +222,7 @@
       * The default behavior of this method is to call 
       * <code>getRenderParameterMap()</code> on the wrapped response object.
       */
-     public Map getRenderParameterMap() {
+     public Map<String, String[]> getRenderParameterMap() {
          return response.getRenderParameterMap();
      }
 
@@ -248,4 +249,21 @@
      public void addProperty(Cookie cookie) {
          response.addProperty(cookie);
      }
+     
+     /**
+      *  The default behavior of this method is to call 
+      * <code>setDefaultNamspacedEvents()</code> on the wrapped response object.
+      */
+ 	public void setDefaultNamspacedEvents(Map<String, Object> events) {
+ 		response.setDefaultNamspacedEvents(events);
+ 	}
+
+     /**
+      *  The default behavior of this method is to call 
+      * <code>setEvent()</code> on the wrapped response object.
+      */
+ 	public void setEvent(String name, Object value) {
+ 		response.setEvent(name, value);
+ 	}
+
 }

Modified: portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/filter/FilterChain.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/filter/FilterChain.java?view=diff&rev=545132&r1=545131&r2=545132
==============================================================================
--- portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/filter/FilterChain.java (original)
+++ portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/filter/FilterChain.java Thu Jun  7 02:59:35 2007
@@ -109,4 +109,6 @@
      */
     public void doFilter(ResourceRequest request, ResourceResponse response)
      throws IOException, PortletException;
+
+
 }

Modified: portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/filter/RenderRequestWrapper.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/filter/RenderRequestWrapper.java?view=diff&rev=545132&r1=545131&r2=545132
==============================================================================
--- portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/filter/RenderRequestWrapper.java (original)
+++ portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/filter/RenderRequestWrapper.java Thu Jun  7 02:59:35 2007
@@ -88,7 +88,7 @@
      * The default behavior of this method is to call 
      * <code>getAttributeNames()</code> on the wrapped request object.
      */
-    public Enumeration getAttributeNames() {
+    public Enumeration<String> getAttributeNames() {
         return request.getAttributeNames();
     }
 
@@ -136,7 +136,7 @@
      * The default behavior of this method is to call 
      * <code>getParameterMap()</code> on the wrapped request object.
      */
-    public Map getParameterMap() {
+    public Map<String, String[]> getParameterMap() {
         return request.getParameterMap();
     }
 
@@ -144,7 +144,7 @@
      * The default behavior of this method is to call 
      * <code>getParameterNames()</code> on the wrapped request object.
      */
-    public Enumeration getParameterNames() {
+    public Enumeration<String> getParameterNames() {
         return request.getParameterNames();
     }
 
@@ -200,7 +200,7 @@
      * The default behavior of this method is to call 
      * <code>getProperteis(name)</code> on the wrapped request object.
      */
-    public Enumeration getProperties(String name) {
+    public Enumeration<String> getProperties(String name) {
         return request.getProperties(name);
     }
 
@@ -216,7 +216,7 @@
      * The default behavior of this method is to call 
      * <code>getPropertyNames()</code> on the wrapped request object.
      */
-    public Enumeration getPropertyNames() {
+    public Enumeration<String> getPropertyNames() {
         return request.getPropertyNames();
     }
 
@@ -248,7 +248,7 @@
      * The default behavior of this method is to call 
      * <code>getResponseContentTypes()</code> on the wrapped request object.
      */
-    public Enumeration getResponseContentTypes() {
+    public Enumeration<String> getResponseContentTypes() {
         return request.getResponseContentTypes();
     }
 
@@ -390,4 +390,5 @@
     public Cookie[] getCookies() {
         return request.getCookies();
     }
+
 }

Modified: portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/filter/RenderResponseWrapper.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/filter/RenderResponseWrapper.java?view=diff&rev=545132&r1=545131&r2=545132
==============================================================================
--- portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/filter/RenderResponseWrapper.java (original)
+++ portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/filter/RenderResponseWrapper.java Thu Jun  7 02:59:35 2007
@@ -24,9 +24,10 @@
  * Community Process. In order to remain compliant with the specification
  * DO NOT add / change / or delete method signatures!
  */
-/**
-  * Copyright 2006 IBM Corporation.
-  */
+/*
+ * Copyright 2006 IBM Corporation.
+ *
+ */
 package javax.portlet.filter;
 
 import java.io.IOException;
@@ -36,6 +37,7 @@
 import java.util.Locale;
 
 import javax.portlet.CacheControl;
+import javax.portlet.PortletMode;
 import javax.portlet.PortletURL;
 import javax.portlet.RenderResponse;
 import javax.portlet.ResourceURL;
@@ -259,7 +261,7 @@
      *  The default behavior of this method is to call 
      * <code>setNextPossiblePortletModes()</code> on the wrapped response object.
      */
-    public void setNextPossiblePortletModes(Enumeration portletModes) {
+    public void setNextPossiblePortletModes(Enumeration<PortletMode> portletModes) {
         response.setNextPossiblePortletModes(portletModes);
     }
 

Modified: portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/filter/ResourceRequestWrapper.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/filter/ResourceRequestWrapper.java?view=diff&rev=545132&r1=545131&r2=545132
==============================================================================
--- portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/filter/ResourceRequestWrapper.java (original)
+++ portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/filter/ResourceRequestWrapper.java Thu Jun  7 02:59:35 2007
@@ -24,9 +24,10 @@
  * Community Process. In order to remain compliant with the specification
  * DO NOT add / change / or delete method signatures!
  */
-/**
-  * Copyright 2006 IBM Corporation.
-  */
+/*
+ * Copyright 2006 IBM Corporation.
+ *
+ */
 package javax.portlet.filter;
 
 import java.io.BufferedReader;
@@ -118,7 +119,7 @@
      * The default behavior of this method is to call 
      * <code>getAttributeNames()</code> on the wrapped request object.
      */
-    public Enumeration getAttributeNames() {
+    public Enumeration<String> getAttributeNames() {
         return request.getAttributeNames();
     }
 
@@ -166,7 +167,7 @@
      * The default behavior of this method is to call 
      * <code>getParameterMap()</code> on the wrapped request object.
      */
-    public Map getParameterMap() {
+    public Map<String, String[]> getParameterMap() {
         return request.getParameterMap();
     }
 
@@ -174,7 +175,7 @@
      * The default behavior of this method is to call 
      * <code>getParameterNames()</code> on the wrapped request object.
      */
-    public Enumeration getParameterNames() {
+    public Enumeration<String> getParameterNames() {
         return request.getParameterNames();
     }
 
@@ -230,7 +231,7 @@
      * The default behavior of this method is to call 
      * <code>getProperteis(name)</code> on the wrapped request object.
      */
-    public Enumeration getProperties(String name) {
+    public Enumeration<String> getProperties(String name) {
         return request.getProperties(name);
     }
 
@@ -246,7 +247,7 @@
      * The default behavior of this method is to call 
      * <code>getPropertyNames()</code> on the wrapped request object.
      */
-    public Enumeration getPropertyNames() {
+    public Enumeration<String> getPropertyNames() {
         return request.getPropertyNames();
     }
 
@@ -278,7 +279,7 @@
      * The default behavior of this method is to call 
      * <code>getResponseContentTypes()</code> on the wrapped request object.
      */
-    public Enumeration getResponseContentTypes() {
+    public Enumeration<String> getResponseContentTypes() {
         return request.getResponseContentTypes();
     }
 

Modified: portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/filter/ResourceResponseWrapper.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/filter/ResourceResponseWrapper.java?view=diff&rev=545132&r1=545131&r2=545132
==============================================================================
--- portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/filter/ResourceResponseWrapper.java (original)
+++ portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/filter/ResourceResponseWrapper.java Thu Jun  7 02:59:35 2007
@@ -24,9 +24,10 @@
  * Community Process. In order to remain compliant with the specification
  * DO NOT add / change / or delete method signatures!
  */
-/**
-  * Copyright 2006 IBM Corporation.
-  */
+/*
+ * Copyright 2006 IBM Corporation.
+ *
+ */
 package javax.portlet.filter;
 
 import java.io.IOException;

Modified: portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/license.txt
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/license.txt?view=diff&rev=545132&r1=545131&r2=545132
==============================================================================
--- portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/license.txt (original)
+++ portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/license.txt Thu Jun  7 02:59:35 2007
@@ -1,47 +1,2 @@
-Copyright © 2003 Sun Microsystems, Inc. and IBM Corporation. All rights 
-reserved.U.S. Government Rights - Commercial software.  Government 
-users are subject to the Sun Microsystems, Inc. standard license 
-agreement and applicable provisions of the FAR and its supplements.  
-Sun,  Sun Microsystems,  the Sun logo,  Java and  Jini are trademarks 
-or registered trademarks of Sun Microsystems, Inc. in the U.S. and 
-other countries.Products covered by and information contained in this 
-service manual are controlled by U.S. Export Control laws and may be 
-subject to the export or import laws in other countries.  Nuclear, 
-missile, chemical biological weapons or nuclear maritime end uses or 
-end users, whether direct or indirect, are strictly prohibited.  Export 
-or reexport to countries subject to U.S. embargo or to entities 
-identified on U.S. export exclusion lists, including, but not limited 
-to, the denied persons and specially designated nationals lists is 
-strictly prohibited.DOCUMENTATION IS PROVIDED "AS IS" AND ALL EXPRESS 
-OR IMPLIED CONDITIONS, REPRESENTATIONS AND WARRANTIES, INCLUDING ANY 
-IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE 
-OR NON-INFRINGEMENT, ARE DISCLAIMED, EXCEPT TO THE EXTENT THAT SUCH 
-DISCLAIMERS ARE HELD TO BE LEGALLY INVALID.
-
-
-
-Copyright © 2003 Sun Microsystems, Inc. et IBM Corporation. Tous droits 
-réservés.Sun,  Sun Microsystems,  le logo Sun,  Java et  Jini sont des 
-marques de fabrique ou des marques déposées de Sun Microsystems, Inc. 
-aux Etats-Unis et dans d'autres pays.
-Les produits qui font l'objet de ce manuel d'entretien et les 
-informations qu'il contient sont regis par la legislation americaine en 
-matiere de controle des exportations et peuvent etre soumis au droit 
-d'autres pays dans le domaine des exportations et importations. Les 
-utilisations finales, ou utilisateurs finaux, pour des armes 
-nucleaires, des missiles, des armes biologiques et chimiques ou du 
-nucleaire maritime, directement ou indirectement, sont strictement 
-interdites. Les exportations ou reexportations vers des pays sous 
-embargo des Etats-Unis, ou vers des entites figurant sur les listes 
-d'exclusion d'exportation americaines, y compris, mais de maniere non 
-exclusive, la liste de personnes qui font objet d'un ordre de ne pas 
-participer, d'une facon directe ou indirecte, aux exportations des 
-produits ou des services qui sont regi par la legislation americaine en 
-matiere de controle des exportations et la liste de ressortissants 
-specifiquement designes, sont rigoureusement interdites.LA 
-DOCUMENTATION EST FOURNIE "EN L'ETAT" ET TOUTES AUTRES CONDITIONS, 
-DECLARATIONS ET GARANTIES EXPRESSES OU TACITES SONT FORMELLEMENT 
-EXCLUES, DANS LA MESURE AUTORISEE PAR LA LOI APPLICABLE, Y COMPRIS 
-NOTAMMENT TOUTE GARANTIE IMPLICITE RELATIVE A LA QUALITE MARCHANDE, A 
-L'APTITUDE A UNE UTILISATION PARTICULIERE OU A L'ABSENCE DE CONTREFACON.
-
+Copyright IBM Corporation. 
+All rights reserved.

Modified: portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/portlet.xml.txt
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/portlet.xml.txt?view=diff&rev=545132&r1=545131&r2=545132
==============================================================================
--- portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/portlet.xml.txt (original)
+++ portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/portlet.xml.txt Thu Jun  7 02:59:35 2007
@@ -7,9 +7,9 @@
     <display-name xml:lang="EN">Time Zone Clock Portlet</display-name>
     <display-name xml:lang="DE">ZeitzonenPortlet</display-name>
     <portlet-class>com.myco.samplets.util.zoneclock.ZoneClock</portlet-class>
-    <expiration-cache>
-    	<expiration-time>-1</expiration-time>
-    </expiration-cache>
+    <caching>
+    	<expiration-cache>-1</expiration-cache>
+    </caching>
     <supports>
       <mime-type>text/html</mime-type>
       <portlet-mode>config</portlet-mode>
--- portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletRequest.java (original)
+++ portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletRequest.java Thu Jun  7 02:59:35 2007
@@ -214,24 +214,12 @@
    * phase the portlet request and response are from type
    * <code>ResourceRequest</code> and <code>ResourceResponse</code>.
    * <p>
    * The value of the constant is <code>RESOURCE_SERVING_PHASE</code>.
    * 
    * @since 2.0
    */
-  public static final String RESOURCE_SERVING_PHASE = "RESOURCE_SERVING_PHASE";
-  
-  /**
-   * String identifier for the portlet fragment serving lifecycle phase. In this
-   * phase the portlet request and response are from type
-   * <code>FragmentRequest</code> and <code>FragmentResponse</code>.
-   * <p>
-   * The value of the constant is <code>FRAGMENT_SERVING_PHASE</code>.
-   * 
-   * @since 2.0
-   */
-  public static final String FRAGMENT_SERVING_PHASE = "FRAGMENT_SERVING_PHASE";
-
-  
+  public static final String RESOURCE_PHASE = "RESOURCE_PHASE";
+    
   /**
    * Provides the portlet lifecycle phase of the current request.
    * <p>
@@ -433,7 +421,7 @@
    *                            if name is <code>null</code>.
    */			
   
-  public java.util.Enumeration getProperties(String name); 
+  public java.util.Enumeration<String> getProperties(String name); 
     
     
   /**
@@ -449,7 +437,7 @@
    *				no properties, an empty <code>Enumeration</code>.
    */
 
-  public java.util.Enumeration getPropertyNames();
+  public java.util.Enumeration<String> getPropertyNames();
     
     
   /**
@@ -584,7 +572,7 @@
    *                    has no attributes available to it.
    */
   
-  public java.util.Enumeration getAttributeNames();
+  public java.util.Enumeration<String> getAttributeNames();
 
 
   /**
@@ -639,7 +627,7 @@
    *			request has no parameters.
    */
 
-  public java.util.Enumeration getParameterNames();
+  public java.util.Enumeration<String> getParameterNames();
 
 
   /**
@@ -685,7 +673,7 @@
    *             String array (<code>String[]</code>).
    */
 
-  public java.util.Map getParameterMap();
+  public java.util.Map<String, String[]> getParameterMap();
 
 
   /**
@@ -815,7 +803,7 @@
    * @return ordered list of MIME types for the response
    */
 
-  public java.util.Enumeration getResponseContentTypes();
+  public java.util.Enumeration<String> getResponseContentTypes();
 
 
   /**
@@ -214,24 +214,12 @@
    * <code>ResourceRequest</code> and <code>ResourceResponse</code>.
    * <p>
-   * The value of the constant is <code>RESOURCE_SERVING_PHASE</code>.
+   * The value of the constant is <code>RESOURCE_PHASE</code>.
    * 
    * @since 2.0

Modified: portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletRequestDispatcher.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletRequestDispatcher.java?view=diff&rev=545132&r1=545131&r2=545132
==============================================================================
--- portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletRequestDispatcher.java (original)
+++ portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletRequestDispatcher.java Thu Jun  7 02:59:35 2007
@@ -25,8 +25,8 @@
  * DO NOT add / change / or delete method signatures!
  */
 /**
-  * Copyright 2006 IBM Corporation.
-  */
+ * Copyright 2006 IBM Corporation.
+ */
 
 package javax.portlet;
 
@@ -53,51 +53,14 @@
      * 
      * 
      * @param request
-     *            a {@link RenderRequest} object that contains the client
-     *            request. Must be either the render request passed to the
-     *            portlet in <code>render</code> or a wrapped version of this
-     *            render request.
-     * 
-     * @param response
-     *            a {@link RenderResponse} object that contains the render
-     *            response. Must be either the render response passed to the
-     *            portlet in <code>render</code> or a wrapped version of this
-     *            render response.
-     * 
-     * @exception PortletException
-     *                if the included resource throws a ServletException, or
-     *                other exceptions that are not Runtime- or IOExceptions.
-     * 
-     * @exception java.io.IOException
-     *                if the included resource throws this exception
-     * 
-     * 
-     */
-
-    public void include(RenderRequest request, RenderResponse response)
-            throws PortletException, java.io.IOException;
-
-    /**
-     * 
-     * Includes the content of a resource (servlet, JSP page, HTML file) in the
-     * response. In essence, this method enables programmatic server-side
-     * includes.
-     * <p>
-     * The included servlet cannot set or change the response status code or set
-     * headers; any attempt to make a change is ignored.
-     * 
-     * 
-     * @param request
-     *            a {@link RenderRequest} object that contains the client
-     *            request. Must be either the resource request passed to the
-     *            portlet in <code>serveResource</code> or a wrapped version
-     *            of this resource request.
+     *            a {@link PortletRequest} object that contains the portlet
+     *            request. Must be either the original request passed to the
+     *            portlet or a wrapped version of this request.
      * 
      * @param response
      *            a {@link ResourceResponse} object that contains the resource
      *            response. Must be either the resource response passed to the
      *            portlet in <code>serveResource</code> or a wrapped version
      *            of this resource response.
      * 
      * @exception PortletException
      *                if the included resource throws a ServletException, or
@@ -105,98 +68,29 @@
      * 
      * @exception java.io.IOException
      *                if the included resource throws this exception
-     * 
-     * @since 2.0
-     */
-
-    public void include(ResourceRequest request, ResourceResponse response)
-            throws PortletException, java.io.IOException;
-
-    /**
-     * 
-     * Includes the content of a servlet in order to delegate the action
-     * processing.
-     * <p>
-     * The included servlet cannot write anything to the outputstream.
-     * 
-     * 
-     * @param request
-     *            a {@link ActionRequest} object that contains the client
-     *            request. Must be either the action request passed to the
-     *            portlet in <code>processAction</code> or a wrapped version
-     *            of this action request.
-     * 
-     * @param response
-     *            a {@link ActionResponse} object that contains the action
-     *            response. Must be either the action response passed to the
-     *            portlet in <code>processAction</code> or a wrapped version
-     *            of this action response.
-     * 
-     * @exception PortletException
-     *                if the included resource throws a ServletException, or
-     *                other exceptions that are not Runtime- or IOExceptions.
-     * 
-     * @exception java.io.IOException
-     *                if the included resource throws this exception
-     * 
-     * @since 2.0
-     */
-
-    public void include(ActionRequest request, ActionResponse response)
-            throws PortletException, java.io.IOException;
-
-    /**
-     * 
-     * Includes the content of a servlet in order to delegate the event
-     * processing.
-     * <p>
-     * The included servlet cannot write anything to the outputstream.
-     * 
-     * 
-     * @param request
-     *            a {@link EventRequest} object that contains the client
-     *            request. Must be either the event request passed to the
-     *            portlet in <code>processEvent</code> or a wrapped version of
-     *            this event request.
-     * 
-     * @param response
-     *            a {@link EventResponse} object that contains the event
-     *            response. Must be either the event response passed to the
-     *            portlet in <code>processEvent</code> or a wrapped version of
-     *            this event response.
-     * 
-     * @exception PortletException
-     *                if the included resource throws a ServletException, or
-     *                other exceptions that are not Runtime- or IOExceptions.
-     * 
-     * @exception java.io.IOException
-     *                if the included resource throws this exception
-     * 
-     * @since 2.0
      */
 
-    public void include(EventRequest request, EventResponse response)
+    public void include(PortletRequest request, PortletResponse response)
             throws PortletException, java.io.IOException;
 
-    
     /**
-     * Forwards a resource request from a portlet to another resource (servlet, JSP file, or HTML file) 
+     * Forwards a portlet request from a portlet to another resource (servlet, JSP file, or HTML file) 
      * on the server. This method allows the portlet to do preliminary processing of a 
      * request and another resource to generate the response.
      * <p>
      * The <code>forward</code> method should be called before the response has been 
-     * committed to the client (before response body output has been flushed). 
+     * committed to the portlet container (before response body output has been flushed). 
      * If the response already has been committed, this method throws an 
      * <code>IllegalStateException</code>. Uncommitted output in the response buffer 
      * is automatically cleared before the forward.
      * <p>
      * The request and response parameters must be either the same objects as were passed to 
-     * the calling portlet's <code>serveResource</code> method or be subclasses of the 
-     * <code>ResourceRequestWrapper</code> or <code>ResourceResponseWrapper</code> classes that wrap them.
+     * the calling portletor be wrapped versions of these.
      * 
-     * @param request  a {@link ResourceRequest} object that represents the request the 
-     *                 client makes of the portlet
-     * @param response a {@link ResourceResponse} object that contains the resource response 
+     * @param request  a request object that represents the request to the 
+     *                 portlet
+     * @param response a reponse object that contains the portlet response
+     *  
      * @exception PortletException
      *                if the included resource throws a ServletException, or
      *                other exceptions that are not Runtime- or IOExceptions.
@@ -206,7 +100,7 @@
      *                if the response was already committed
      * @since 2.0
      */
-    public void forward(ResourceRequest request, ResourceResponse response)
+    public void forward(PortletRequest request, PortletResponse response)
             throws PortletException, java.io.IOException, java.lang.IllegalStateException;
 
     
@@ -53,51 +53,14 @@
      * 
      * @param response
-     *            a {@link ResourceResponse} object that contains the resource
-     *            response. Must be either the resource response passed to the
-     *            portlet in <code>serveResource</code> or a wrapped version
-     *            of this resource response.
+     *            a {@link PortletResponse} object that contains the portlet
+     *            response. Must be either the portlet response passed to the
+     *            portlet or a wrapped version of this response.
      * 
      * @exception PortletException

Modified: portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletResponse.java
URL: http://svn.apache.org/viewvc/portals/pluto/branches/1.1-286-COMPATIBILITY/portlet2-api/src/main/java/javax/portlet/PortletResponse.java?view=diff&rev=545132&r1=545131&r2=545132
==============================================================================